@@ -152,13 +152,14 @@ static time_t mktime_from_rfc2616(const char *date) {
 /*
  * SYNOPSIS:
  *   double set_clock(
- *                    struct timeval *tvinfo,
+ *                    const struct timeval *tvdata
  *                    int allow_adj,
  *                    int ignoreusec
  *                   );
  *
  * ARGUMENTS:
- *   struct timeval *tvinfo  Pointer to time value to set clock to. (GMT/UTC)
+ *   const struct timeval *tvdata  Pointer to time value to set clock to
+ *                                 (GMT/UTC)
  *   int allow_adj           Set to 1 if you want to allow time to be "Slew"'d
  *                           if the OS supports this.
  *   int ignoreusec          Set to non-zero if you want to ignore the usec
@@ -173,23 +174,32 @@ static time_t mktime_from_rfc2616(const char *date) {
  *   value as if no adjustment was needed.
  *
  */
-double set_clock(struct timeval *tvinfo, int allow_adj, int ignoreusec) {
+double set_clock(const struct timeval *tvdata, int allow_adj, int ignoreusec) {
 	struct timeval tvdelta;
+	struct timeval tvinfo;
 	double retval = 0.0;
 	int chkret = -1;
 
 	gettimeofday(&tvdelta, NULL);
 
+	tvinfo.tv_sec = tvdata->tv_sec;
+	tvinfo.tv_usec = tvdata->tv_usec;
+
 	if (ignoreusec) {
-		tvinfo->tv_usec = tvdelta.tv_usec;
+		tvinfo.tv_usec = tvdelta.tv_usec;
+	}
+
+	tvdelta.tv_sec = tvinfo.tv_sec - tvdelta.tv_sec;
+	tvdelta.tv_usec = tvinfo.tv_usec - tvdelta.tv_usec;
+
+	if (tvdelta.tv_sec == 0 && tvdelta.tv_usec == 0) {
+#ifdef HAVE_SYSLOG
+		syslog(LOG_NOTICE, "Skipping adjustment, clock is already correct.");
+		return(retval);
+#endif
 	}
 
 #ifdef HAVE_ADJTIME
-	if (allow_adj) {
-		tvdelta.tv_sec = tvinfo->tv_sec - tvdelta.tv_sec;
-		tvdelta.tv_usec = tvinfo->tv_usec - tvdelta.tv_usec;
-	}
-
 	if ((tvdelta.tv_sec < 60 && tvdelta.tv_sec > -60) && allow_adj) {
 		chkret = adjtime(&tvdelta, NULL);
 		if (chkret >= 0) {
@@ -202,10 +212,10 @@ double set_clock(struct timeval *tvinfo, int allow_adj, int ignoreusec) {
 #endif
 
 	if (chkret < 0) {
-		chkret = settimeofday(tvinfo, NULL);
+		chkret = settimeofday(&tvinfo, NULL);
 		if (chkret >= 0) {
-			retval = (tvinfo->tv_sec - tvdelta.tv_sec) + (((double) (tvinfo->tv_usec - tvdelta.tv_usec)) / 1000000.0);
-#ifdef HAVE_SYSLOG
+			retval = tvdelta.tv_sec + (((double) tvdelta.tv_usec) / 1000000.0);
+#ifdef HAVE_SYSLOOCCOC
 			syslog(LOG_NOTICE, "Adjusting clock by %f seconds (step).", retval);
 #endif
 		}
@@ -527,6 +537,9 @@ struct timeval *htp_calctime(struct timeserver_st *timeservers, unsigned int tot
 		if (totaltimes == 2) {
 			newtimeval = &avgtime;
 		} else {
+			/* Initialize those values.. yeah.. */
+			stddevavgtime.tv_sec = 0;
+			stddevavgtime.tv_usec = 0;
 
 			/* Otherwise we only include values within one standard deviation */
 			stddevtimes = ((double) totaltimes) * 0.34; /* One standard deviation, +/- 34% about the mean. */
