@@ -3,6 +3,12 @@
 #endif
 #include "win32.h"
 
+#ifdef HAVE_SYS_STAT_H
+#include <sys/stat.h>
+#endif
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
 #ifdef HAVE_MATH_H
 #include <math.h>
 #endif
@@ -59,6 +65,8 @@
 #define LOOP_STOP 1
 #define LOOP_DONE 2
 
+#define SKIPSTARTFILE SYSCONFDIR "/htp-disable"
+
 /*
  * This global variable is used to coordinate the shutdown of the main work
  * loop (htpd_loop()).
@@ -121,7 +129,7 @@ int htpd_loop(void) {
 	while (1) {
 		newtime = htp_calctime(timeservers, totaltimeservers, http_proxy, http_proxy_port);
 
-		if (newtime >= 0) {
+		if (newtime != NULL) {
 			delta = set_clock(newtime, 1, 1);
 		} else {
 			delta = 0.0;
@@ -299,6 +307,8 @@ static int daemon_init(void) {
 	FILE *pidfile_fp = NULL;
 	pid_t pid;
 
+	unlink(SKIPSTARTFILE);
+
 	close(STDIN_FILENO);
 	close(STDOUT_FILENO);
 	close(STDERR_FILENO);
@@ -458,7 +468,12 @@ static int daemon_stop(void) {
  *   is returned.  Otherwise -1 is returned.
  *
  * NOTES:
- *   This function only does something useful on win32 right now.
+ *   On win32 this does the services thing.
+ *
+ *   Otherwise, it cooperates with the supplied "htpd.init" script to manage
+ *   the SKIPSTARTFILE.  If this file exists, the "htpd.init" script's start
+ *   action aborts.  htpd deletes the file upon sucessful startup.  This
+ *   function creates the file and stops the running daemon.
  *
  */
 static int daemon_remove(void) {
@@ -468,10 +483,12 @@ static int daemon_remove(void) {
 	stop_ret = daemon_stop();
 
 	if (stop_ret < 0) {
-		return(stop_ret);
+		retval = -1;
 	}
-#ifndef _USE_WIN32_
 
+#ifndef _USE_WIN32_
+	creat(SKIPSTARTFILE, 0600);
+	retval = 0;
 #else
 	if (manager == NULL) {
 		manager = OpenSCManager(NULL, NULL, SC_MANAGER_ALL_ACCESS);
