@@ -25,7 +25,7 @@ int settimeofday(const struct timeval *tv , void *tz) {
 	struct tm *lt = NULL;
 	SYSTEMTIME st;
 
-	lt = localtime(&(tv->tv_sec));
+	lt = gmtime(&(tv->tv_sec));
 
 	st.wYear = lt->tm_year + 1900;
 	st.wMonth = lt->tm_mon + 1;
